shithub: pokered

Download patch

ref: f38ee046c076878bacbe6ad3eb7cf0281f264de3
parent: bb76c06120bcd1fc0f86bd3cc96cbbde93c0c80c
parent: 6b8ddb6beb6e2c22d89abc2863d4660a9d94cab8
author: Daniel Harding <33dannye@gmail.com>
date: Wed Dec 2 04:21:48 EST 2020

Merge pull request #306 from SatoMew/master

Update tileset header comments

--- a/data/tilesets/tileset_headers.asm
+++ b/data/tilesets/tileset_headers.asm
@@ -3,11 +3,11 @@
 	dw \1, \2, \3 ; Block, GFX, Coll
 	db \4, \5, \6 ; counter tiles
 	db \7         ; grass tile
-	db \8         ; permission (indoor, cave, outdoor)
+	db \8         ; animations (TILEANIM_* value)
 ENDM
 
 Tilesets:
 	; block, gfx, coll, 3 counter tiles, grass tile, permission
 	tileset Overworld_Block,   Overworld_GFX,   Overworld_Coll,   $FF,$FF,$FF, $52, TILEANIM_WATER_FLOWER
 	tileset RedsHouse1_Block,  RedsHouse1_GFX,  RedsHouse1_Coll,  $FF,$FF,$FF, $FF, TILEANIM_NONE
 	tileset Mart_Block,        Mart_GFX,        Mart_Coll,        $18,$19,$1E, $FF, TILEANIM_NONE
@@ -3,11 +3,11 @@
 
 Tilesets:
-	; block, gfx, coll, 3 counter tiles, grass tile, permission
+	; block, gfx, coll, 3 counter tiles, grass tile, animations
 	tileset Overworld_Block,   Overworld_GFX,   Overworld_Coll,   $FF,$FF,$FF, $52, TILEANIM_WATER_FLOWER
 	tileset RedsHouse1_Block,  RedsHouse1_GFX,  RedsHouse1_Coll,  $FF,$FF,$FF, $FF, TILEANIM_NONE